Format

Enum Format 

pub enum Format {
    Simple,
    LibSystemD,
    RFC,
}
String formats available during transformation from an ID into text

Variants:

  • Simple: 0000-0000-0000-0000-0000-0000-0000-0000
  • LibSystemD: 00000000000000000000000000000000, this format is applied on all formatting performed by calling FFI functionality
  • RFC: 00000000-0000-0000-0000-000000000000, this format is applied by default to all native formatting

Variants



Simple



LibSystemD



RFC